@@ -83,7 +83,6 @@ describe 'gnocchi::keystone::authtoken' do
           :memcache_security_strategy           => 'ENCRYPT',
           :memcache_use_advanced_pool           => true,
           :memcached_servers                    => ['memcached01:11211','memcached02:11211'],
-          :manage_memcache_package              => true,
           :region_name                          => 'region2',
           :revocation_cache_time                => '11',
           :signing_dir                          => '/var/cache',
@@ -128,10 +127,6 @@ describe 'gnocchi::keystone::authtoken' do
         is_expected.to contain_gnocchi_config('keystone_authtoken/signing_dir').with_value(params[:signing_dir])
         is_expected.to contain_gnocchi_config('keystone_authtoken/token_cache_time').with_value(params[:token_cache_time])
       end
-
-      it 'installs python memcache package' do
-        is_expected.to contain_package('python-memcache')
-      end
     end
   end
 
