@@ -8,6 +8,7 @@ describe 'gnocchi::storage' do
 
   shared_examples_for 'gnocchi-storage' do
 
+    it { is_expected.to contain_class('gnocchi::deps') }
     it { is_expected.to contain_class('gnocchi::params') }
 
     it 'installs gnocchi-carbonara package' do
@@ -20,15 +21,11 @@ describe 'gnocchi::storage' do
 
     context 'with coordination' do
       before do
-        params.merge!({
-          :coordination_url        => 'redis://localhost:6379',
-          :metric_processing_delay => 30,
-        })
+        params.merge!({ :coordination_url => 'redis://localhost:6379' })
       end
 
       it 'configures backend_url' do
         is_expected.to contain_gnocchi_config('storage/coordination_url').with_value('redis://localhost:6379')
-        is_expected.to contain_gnocchi_config('storage/metric_processing_delay').with_value(30)
       end
     end
   end
